#!/etc/opt/openit/perl -w
#
# This script updates the flexlog.conf file
# to include object for the include/exclude file
#
use strict;

my $cfg = "/var/opt/openit/etc/flexlog.conf";
my $old = "/var/opt/openit/etc/flexlog.old";
my $new = "/var/opt/openit/etc/flexlog.new";

# Only root can patch
if ( $< ne 0 ) {
    die "Error: Patching must be done as 'root'!\n";
}

open(IN, "$cfg") || die "Error: Unable to read old cfg '$cfg'!\n";

# Read old config
my @config = <IN>;
close(IN);

my $ind = 0;

my $dt_start;
my $dt_stop;

# Check if change already done (and find insert position)
my $insert_pos = 0;
my $change_done = 0;
while($config[$ind]) {
    if ($config[$ind] =~ /include_exclude/) {
	$change_done = 1;
	last;
    }
    if ($config[$ind] =~ /datalog/) {
	$insert_pos = $ind;
    }
    $ind++;
}

# Check if change already done
if ($change_done) {
    print STDERR "Warning: flexlog update already applied!\n";
    exit 0;
}

# Insert new config object
splice @config, $insert_pos, 0,
  "        include_exclude(FileName)=\"\${OpeniT.directories.conf}license.exclude\"{}\n";

open(OUT, ">$new") || die "Error: Can't write new cfg '$new'!\n";
print OUT @config;
close(OUT);

if( ! rename($cfg, $old)) {
    die "Error: Unable to previous config to '$old'!\n";
}

if( ! rename($new, $cfg)) {
    die "Error: Unable to rename new config to '$cfg'!\n";
}

exit 0;
